==> snooty-lextudio-1.9.1.dev0.tar.gz: snooty-lextudio-1.9.1.dev0/CHANGELOG.lextudio.md <==
## [v1.9.1] - 2021-05-02

### Fixed

- Revised hover file path resolution. ([GitHub-23](https://github.com/vscode-restructuredtext/snooty-parser/issues/23))

## [v1.9.0] - 2021-04-22

### Changed

- Sync up with upstream.

## [v1.8.10] - 2021-02-26

### Fixed

- Added an autocompletion crash. ([GitHub-20](https://github.com/vscode-restructuredtext/snooty-parser/issues/20))

### Changed

- Sync up with upstream.

## [v1.8.9] - 2021-02-20

### Fixed

- Added a few more common roles.

### Changed

- Sync up with upstream.

## [v1.8.8] - 2021-02-19

### Fixed

- Added code role. ([GitHub-18](https://github.com/vscode-restructuredtext/snooty-parser/issues/18))

### Changed

- Sync up with upstream.

## [v1.8.7] - 2021-02-05

### Fixed

- Added code role. ([GitHub-16](https://github.com/vscode-restructuredtext/snooty-parser/issues/16))

## [v1.8.6] - 2020-12-19

### Fixed

- Changed file path resolution so it only appends extensions when necessary. ([GitHub-10](https://github.com/vscode-restructuredtext/snooty-parser/issues/10))

## [v1.8.4] - 2020-12-18

### Added

- Implemented file name autocompletion based on rstantlr ([GitHub-9](https://github.com/vscode-restructuredtext/snooty-parser/issues/9))

### Fixed

- Fixed the crash on `/` path ([GitHub-8](https://github.com/vscode-restructuredtext/snooty-parser/issues/8))

## [v1.8.3] - 2020-12-15

### Fixed

- Fixed Uri/Path conversion issues on Windows ([GitHub-5](https://github.com/vscode-restructuredtext/snooty-parser/issues/5))

## [v1.8.2] - 2020-12-15

### Fixed

- Fixed :doc: referenced file extension detection ([GitHub-3](https://github.com/vscode-restructuredtext/snooty-parser/issues/3))
- Fixed project source path ([GitHub-4](https://github.com/vscode-restructuredtext/snooty-parser/issues/4))

==> snooty-lextudio-1.9.2.dev0.tar.gz: snooty-lextudio-1.9.2.dev0/CHANGELOG.lextudio.md <==
## [v1.9.2] - 2021-05-15

### Changed

- Sync up with upstream.

### Fixed

- Added csv-table directive. ([GitHub-22](https://github.com/vscode-restructuredtext/snooty-parser/issues/22))

## [v1.9.1] - 2021-05-02

### Fixed

- Revised hover file path resolution. ([GitHub-23](https://github.com/vscode-restructuredtext/snooty-parser/issues/23))

## [v1.9.0] - 2021-04-22

### Changed

- Sync up with upstream.

## [v1.8.10] - 2021-02-26

### Fixed

- Resolved an autocompletion crash. ([GitHub-20](https://github.com/vscode-restructuredtext/snooty-parser/issues/20))

### Changed

- Sync up with upstream.

## [v1.8.9] - 2021-02-20

### Fixed

- Added a few more common roles.

### Changed

- Sync up with upstream.

## [v1.8.8] - 2021-02-19

### Fixed

- Added code role. ([GitHub-18](https://github.com/vscode-restructuredtext/snooty-parser/issues/18))

### Changed

- Sync up with upstream.

## [v1.8.7] - 2021-02-05

### Fixed

- Added code role. ([GitHub-16](https://github.com/vscode-restructuredtext/snooty-parser/issues/16))

## [v1.8.6] - 2020-12-19

### Fixed

- Changed file path resolution so it only appends extensions when necessary. ([GitHub-10](https://github.com/vscode-restructuredtext/snooty-parser/issues/10))

## [v1.8.4] - 2020-12-18

### Added

- Implemented file name autocompletion based on rstantlr ([GitHub-9](https://github.com/vscode-restructuredtext/snooty-parser/issues/9))

### Fixed

- Fixed the crash on `/` path ([GitHub-8](https://github.com/vscode-restructuredtext/snooty-parser/issues/8))

## [v1.8.3] - 2020-12-15

### Fixed

- Fixed Uri/Path conversion issues on Windows ([GitHub-5](https://github.com/vscode-restructuredtext/snooty-parser/issues/5))

## [v1.8.2] - 2020-12-15

### Fixed

- Fixed :doc: referenced file extension detection ([GitHub-3](https://github.com/vscode-restructuredtext/snooty-parser/issues/3))
- Fixed project source path ([GitHub-4](https://github.com/vscode-restructuredtext/snooty-parser/issues/4))
